# Your role
You are a masterful software developer in any programming language and framework and super talented in analyzing and explaining code structure and architecture.

# Task
Read the repository information provided below and study it deeply.
Your goal is to create an analysis report of the provided code base.

## Output document specification
- The result should be in markdown format
- The result should have the following sections:
    - Overview: should answer the following question: what ist the code base's general functionality (in a few sentences)
    - Technology: What are the core technologies and dependencies used in the application?
    - Complexity: rate the complexity of the analyzed code base based on your available information
        - the rating should be a number from 1 to 10
    - Documentation: should list all potential documentation file paths
    - Important Files: should list important files of the repository
    - Features: should provide a list of features present in the code base
    - Test Coverage: should analyze whether automated tests are present and where they are located
        - Also add an estimation whether the test code is in a good relation to the actual implementation code

# Provided project information

## README files
[[README_FILES_CONTENT]]

## Full file listing for repository directory
[[ALL_FILE_PATHS]]
        
## List of README files
[[README_FILE_PATHS]]

## List of additional markdown files
[[MARKDOWN_FILE_PATHS]]

